pro convert_deimos_to_specpro, spec1dfile, slitBfile, slitRfile, out1dname=out1dname, out2dname=out2dname
  
;Wrapper to convert DEIMOS spectra reduced with the DEEP2 pipeline to 
;the format readable by specpro.pro.
;
; Inputs:
;
; spec1dfile - The 1D spectrum to convert, in fits format with the blue
;              and red ends of the spectrum stored in extensions 1
;              and 2, respectively.
; slitBfile -  The blue 2D spectrum fits file.
; slitRfile -  The red 2D spectrum fits file.
; out1dname -  Optional string input specifying the name of the 1D
;              file for SpecPro. Note that it must follow the general
;              format spec1d.[mask name].[3 digit slit number].[target
;              name].fits. The default name is
;              spec1d.mask.000.object.fits.
; out2dname  - Optional string input giving 2D file name for
;              SpecPro. Default is spec2d.mask.000.object.fits.


if n_elements(out1dname) eq 0 then begin
   out1dname = 'spec1d.mask.000.object.fits'
endif
if n_elements(out2dname) eq 0 then begin
   out2dname = 'spec2d.mask.000.object.fits'
endif

spec1dblue = mrdfits(spec1dfile,1)
spec1dred = mrdfits(spec1dfile,2)

new1d = {flux:[double(spec1dblue.spec), double(spec1dred.spec)], ivar:[double(spec1dblue.ivar), double(spec1dred.ivar)], lambda:[double(spec1dblue.lambda), double(spec1dred.lambda)]}

mwrfits, new1d, out1dname, /create

;-------------------------
;Now convert 2D.
spec2dblue = mrdfits(slitBfile,1)
spec2dred  = mrdfits(slitRfile,1)

sz = size(spec2dblue.dlambda)
bluearr = dblarr(sz[1],sz[2])
for i = 0, sz[2]-1 do begin
   bluearr[*,i]=spec2dblue.lambda0
endfor

newbluelambda = spec2dblue.dlambda + bluearr
 
sz = size(spec2dred.dlambda)
redarr = dblarr(sz[1],sz[2])
for i = 0, sz[2]-1 do begin
   redarr[*,i]=spec2dred.lambda0
endfor

newredlambda = spec2dred.dlambda + redarr

;check that y dimensions match; if they do not, then stitch them
;together using smaller of the y pixel dimension.

szblue = size(spec2dblue.flux)
szred = size(spec2dred.flux)

ykeep = min([szblue[2], szred[2]])

newflux = [spec2dblue.flux[*,0:ykeep-1], spec2dred.flux[*,0:ykeep-1]]
newivar = [spec2dblue.ivar[*,0:ykeep-1], spec2dred.ivar[*,0:ykeep-1]]
newlambda = [newbluelambda[*,0:ykeep-1], newredlambda[*,0:ykeep-1]]

new2d = {flux:double(newflux), lambda:double(newlambda), ivar:double(newivar)}

mwrfits, new2d, out2dname, /create

end ;convert_deimos_to_specpro
